You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@poi.apache.org by bu...@apache.org on 2014/08/17 16:27:04 UTC

[Bug 56854] XMLBeans performance when using getXXXList() and other proxy methods

https://issues.apache.org/bugzilla/show_bug.cgi?id=56854

--- Comment #1 from Yaniv Kunda <ya...@kundas.net> ---
Created attachment 31921
  --> https://issues.apache.org/bugzilla/attachment.cgi?id=31921&action=edit
Preliminary optimizations

This is a first sweep of proxy method usages, which includes mostly usage of
array-based proxy methods instead of list-based when appropriate, and other
repeat calls of methods inlined.

test-all runtime dropped from ~80 seconds to ~60 on my machine, mostly due to
the changes in XSSF and ColumnHelper.

-- 
You are receiving this mail because:
You are the assignee for the bug.

---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@poi.apache.org
For additional commands, e-mail: dev-help@poi.apache.org